@@ -117,6 +117,7 @@ class SchemaMeta(ABCMeta):
             klass=klass,
             cls_fields=cls_fields,
             inherited_fields=inherited_fields,
+            dict_cls=dict,
         )
         return klass
 
@@ -211,6 +212,7 @@ class SchemaOpts:
             warnings.warn(
                 "The json_module class Meta option is deprecated. Use render_module instead.",
                 RemovedInMarshmallow4Warning,
+                stacklevel=2,
             )
             render_module = getattr(meta, "json_module", json)
         else:
