@@ -6,5 +6,6 @@
 """
 import typing
 
-StrSequenceOrSet = typing.Union[typing.Sequence[str], typing.Set[str]]
+StrSequenceOrSet = typing.Union[typing.Sequence[str], typing.AbstractSet[str]]
 Tag = typing.Union[str, typing.Tuple[str, bool]]
+Validator = typing.Callable[[typing.Any], typing.Any]
